@@ -12,6 +12,8 @@ msg = """VPS toolkits 😏
 -k(--kill) process ::: Kill linux process.
 -p(--phone) ::: Papa phone monitor.
 -socks [port] ::: Set up a socks5 proxy.
+
+-flow(--dataflow)::: papa cellphone dataflow monitor.
 """
 
 
@@ -21,6 +23,7 @@ def parse_arguments():
     sp.add_argument('-k', '--kill')
     sp.add_argument('-p', '--phone')
     sp.add_argument('-socks', '--socks')
+    sp.add_argument('-flow', '--dataflow')
     sp.parse_args()
 
     if sp.monitor:
@@ -36,6 +39,11 @@ def parse_arguments():
         port = sp.socks.value
         if port == 'PLACEHOLDER': port = 8888
         Network.setup_socks5_proxy(port)
+
+    elif sp.dataflow:
+        from .crontab import papa_phone_dataflow
+        papa_phone_dataflow()
+
     else:
         for l in msg.split("\n"):
             c, e = (l + " ::: ").split(':::')[:2]
